/*
 * Copyright 2002-2005 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.ldaptemplate.support.acegi;

import javax.naming.directory.Attributes;

import org.acegisecurity.providers.ldap.LdapAuthenticationProvider;
import org.acegisecurity.providers.ldap.LdapAuthenticator;
import org.acegisecurity.providers.ldap.LdapAuthoritiesPopulator;
import org.acegisecurity.userdetails.UserDetails;

/**
 * LdapTemplate-specific subclass of Acegi's LdapAuthenticationProvider. There
 * is no difference in how this implementation is used as compared to its
 * superclass, but it is needed because we must have the distinguished name of
 * the logged in user available in order to use it as Principal when creating
 * Contexts. To accomplish this, we override
 * {@link #createUserDetails(String, String, String, Attributes)} to return a
 * {@link net.sf.ldaptemplate.support.acegi.LdapTemplateUser} instance.
 * 
 * @author Mattias Arthursson
 * 
 */
public class LdapTemplateLdapAuthenticationProvider extends
        LdapAuthenticationProvider {

    /**
     * TODO: We have a really ugly hack here - since LdapAuthenticationProvider
     * does not have a getter for its LdapAuthortiesPopulator, we need to save a
     * reference to it in this class too, since it's needed in
     * createUserDetails. This problem is in Acegi 1.0 RC2 and is fixed in the
     * next (final?) release. Once that is available this field should be
     * removed.
     */
    private LdapAuthoritiesPopulator authoritiesPopulator;

    public LdapTemplateLdapAuthenticationProvider(
            LdapAuthenticator authenticator,
            LdapAuthoritiesPopulator authoritiesPopulator) {
        super(authenticator, authoritiesPopulator);
        this.authoritiesPopulator = authoritiesPopulator;
    }

    protected UserDetails createUserDetails(String username, String password,
            String userDn, Attributes attributes) {
        return new LdapTemplateUser(username, password, true, true, true, true,
                authoritiesPopulator.getGrantedAuthorities(username, userDn,
                        attributes), userDn);
    }
}
