package net.sf.ldaptemplate.support.acegi;

import org.acegisecurity.GrantedAuthority;
import org.acegisecurity.userdetails.User;

/**
 * In order to use the principals Acegi created on login, we need to include the
 * Ldap DN of the user in order to use it for individual login to LdapTemplate.
 * 
 * @author Mattias Arthursson
 * 
 */
public class LdapTemplateUser extends User {
    private static final long serialVersionUID = 3800007801214945392L;

    private final String dn;

    public LdapTemplateUser(String username, String password,
            boolean enabled, boolean accountNonExpired,
            boolean credentialsNonExpired, boolean accountNonLocked,
            GrantedAuthority[] authorities, String dn) {
        super(username, password, enabled, accountNonExpired,
                credentialsNonExpired, accountNonLocked, authorities);
        this.dn = dn;
    }

    /**
     * Get the DN of the user.
     * 
     * @return the distinguished name of the logged in user.
     */
    public String getDn() {
        return dn;
    }
}
