/*
 * Copyright 2002-2005 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.ldaptemplate.support.acegi;

import junit.framework.TestCase;

import org.acegisecurity.Authentication;
import org.acegisecurity.GrantedAuthority;
import org.acegisecurity.context.SecurityContextHolder;
import org.acegisecurity.userdetails.User;
import org.easymock.MockControl;

public class AcegiAuthenticationSourceTest extends TestCase {

    private MockControl authenticationControl;

    private Authentication authenticationMock;

    private AcegiAuthenticationSource tested;

    protected void setUp() throws Exception {
        super.setUp();

        authenticationControl = MockControl.createControl(Authentication.class);
        authenticationMock = (Authentication) authenticationControl.getMock();

        tested = new AcegiAuthenticationSource();
    }

    protected void tearDown() throws Exception {
        super.tearDown();

        authenticationControl = null;
        authenticationMock = null;

        tested = null;
    }

    protected void replay() {
        authenticationControl.replay();
    }

    protected void verify() {
        authenticationControl.verify();
    }

    /*
     * Test method for
     * 'net.sf.ldaptemplate.support.AcegiAuthenticationSource.getPrincipal()'
     */
    public void testGetPrincipalAndCredentials() {
        authenticationControl.expectAndReturn(
                authenticationMock.getPrincipal(), new LdapTemplateUser(
                        "dummy", "dummy", true, true, true, true,
                        new GrantedAuthority[0], "cn=Manager"));
        authenticationControl.expectAndReturn(authenticationMock
                .getCredentials(), "secret");

        SecurityContextHolder.getContext()
                .setAuthentication(authenticationMock);

        replay();

        String principal = tested.getPrincipal();
        String credentials = tested.getCredentials();

        verify();

        assertEquals("secret", credentials);
        assertEquals("cn=Manager", principal);
    }

    public void testGetPrincipalAndCredentials_nullAuthentication() {
        SecurityContextHolder.getContext().setAuthentication(null);

        replay();

        assertEquals("", tested.getPrincipal());
        assertEquals("", tested.getCredentials());
        verify();
    }

    public void testGetPrincipal_InvalidPrincipal() {
        authenticationControl.expectAndReturn(
                authenticationMock.getPrincipal(), new User("dummy", "dummy",
                        true, true, true, true, new GrantedAuthority[0]));

        SecurityContextHolder.getContext()
                .setAuthentication(authenticationMock);

        replay();

        try {
            tested.getPrincipal();
            fail("IllegalArgumentException expected");
        } catch (IllegalArgumentException expected) {
            assertTrue(true);
        }
        verify();
    }
}
