/*
 * Copyright 2002-2005 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.ldaptemplate.support.acegi;

import javax.naming.directory.BasicAttributes;

import junit.framework.TestCase;

import org.acegisecurity.GrantedAuthority;
import org.acegisecurity.providers.ldap.LdapAuthenticator;
import org.acegisecurity.providers.ldap.LdapAuthoritiesPopulator;
import org.acegisecurity.userdetails.UserDetails;
import org.easymock.MockControl;

public class LdapTemplateLdapAuthenticationProviderTest extends TestCase {

    private MockControl ldapAuthenticatorControl;

    private LdapAuthenticator ldapAuthenticatorMock;

    private MockControl ldapAuthorotiesPopulatorControl;

    private LdapAuthoritiesPopulator ldapAuthorotiesPopulatorMock;

    private LdapTemplateLdapAuthenticationProvider tested;

    protected void setUp() throws Exception {
        super.setUp();
        ldapAuthenticatorControl = MockControl
                .createControl(LdapAuthenticator.class);
        ldapAuthenticatorMock = (LdapAuthenticator) ldapAuthenticatorControl
                .getMock();

        ldapAuthorotiesPopulatorControl = MockControl
                .createControl(LdapAuthoritiesPopulator.class);
        ldapAuthorotiesPopulatorMock = (LdapAuthoritiesPopulator) ldapAuthorotiesPopulatorControl
                .getMock();

        tested = new LdapTemplateLdapAuthenticationProvider(
                ldapAuthenticatorMock, ldapAuthorotiesPopulatorMock);
    }

    protected void tearDown() throws Exception {
        super.tearDown();

        ldapAuthenticatorControl = null;
        ldapAuthenticatorMock = null;

        ldapAuthorotiesPopulatorControl = null;
        ldapAuthorotiesPopulatorMock = null;

        tested = null;
    }

    protected void replay() {
        ldapAuthenticatorControl.replay();
        ldapAuthorotiesPopulatorControl.replay();
    }

    protected void verify() {
        ldapAuthenticatorControl.verify();
        ldapAuthorotiesPopulatorControl.verify();
    }

    public void testCreateUserDetails() {
        BasicAttributes attributes = new BasicAttributes();
        GrantedAuthority[] grantedAuthorities = new GrantedAuthority[0];

        String dn = "cn=Some Person, ou=somecompany, dc=jayway, dc=se";
        ldapAuthorotiesPopulatorControl.expectAndReturn(
                ldapAuthorotiesPopulatorMock.getGrantedAuthorities("someUser",
                        dn, attributes), grantedAuthorities);
        replay();

        UserDetails details = tested.createUserDetails("someUser",
                "somepassword", dn, attributes);

        verify();

        assertTrue("Should be an instance of LdapTemplateUser",
                details instanceof LdapTemplateUser);
        LdapTemplateUser result = (LdapTemplateUser) details;
        assertEquals("someUser", result.getUsername());
        assertEquals("somepassword", result.getPassword());
        assertSame(grantedAuthorities, result.getAuthorities());
        assertSame(dn, result.getDn());
    }
}
